@@ -9,7 +9,7 @@ from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
-def test_auto_mapper_array_single_item_with_mapper(spark_session: SparkSession):
+def test_auto_mapper_array_single_item_with_mapper(spark_session: SparkSession) -> None:
     # Arrange
     spark_session.createDataFrame(
         [
@@ -29,7 +29,7 @@ def test_auto_mapper_array_single_item_with_mapper(spark_session: SparkSession):
         view="members",
         source_view="patients",
         keys=["member_id"]
-    ).withColumn(
+    ).columns(
         dst2=A.list(
             A.complex(
                 addr="address1"
@@ -38,7 +38,7 @@ def test_auto_mapper_array_single_item_with_mapper(spark_session: SparkSession):
     )
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs()
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
