@@ -5,7 +5,7 @@ from pyspark.sql import SparkSession, Column, DataFrame
 from spark_auto_mapper.automappers.automapper import AutoMapper
 
 
-def test_auto_mapper_multiple_columns_simpler_syntax(spark_session: SparkSession):
+def test_auto_mapper_multiple_columns_simpler_syntax(spark_session: SparkSession) -> None:
     # Arrange
     spark_session.createDataFrame(
         [
@@ -25,18 +25,18 @@ def test_auto_mapper_multiple_columns_simpler_syntax(spark_session: SparkSession
         view="members",
         source_view="patients",
         keys=["member_id"]
-    ).withColumn(
+    ).columns(
         dst1="src1"
-    ).withColumn(
+    ).columns(
         dst2=[
             "address1"
         ]
-    ).withColumn(
+    ).columns(
         dst3=[
             "address1",
             "address2"
         ]
-    ).withColumn(
+    ).columns(
         dst4=[
             dict(
                 use="usual",
@@ -46,7 +46,7 @@ def test_auto_mapper_multiple_columns_simpler_syntax(spark_session: SparkSession
     )
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs()
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
