@@ -5,7 +5,7 @@ from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
-def test_auto_mapper_full(spark_session_per_function: SparkSession):
+def test_auto_mapper_full(spark_session_per_function: SparkSession) -> None:
     spark_session: SparkSession = spark_session_per_function
     # Arrange
     spark_session.createDataFrame(
@@ -18,9 +18,6 @@ def test_auto_mapper_full(spark_session_per_function: SparkSession):
 
     source_df: DataFrame = spark_session.table("patients")
 
-    df = source_df.select("member_id")
-    df.createOrReplaceTempView("members")
-
     # example of a variable
     client_address_variable: str = "address1"
 
@@ -29,22 +26,16 @@ def test_auto_mapper_full(spark_session_per_function: SparkSession):
         view="members",
         source_view="patients",
         keys=["member_id"]
-    ).withColumn(
-        dst1="src1"
-    ).withColumn(
-        dst2=A.list(
-            client_address_variable
-        )
-    ).withColumn(
-        dst3=A.list(
-            [client_address_variable, "address2"]
-        )
+    ).columns(
+        dst1="src1",
+        dst2=A.list(client_address_variable),
+        dst3=A.list([client_address_variable, "address2"])
     )
 
     company_name: str = "Microsoft"
 
     if company_name == "Microsoft":
-        mapper = mapper.withColumn(
+        mapper = mapper.columns(
             dst4=A.list(
                 A.complex(
                     use="usual",
@@ -53,11 +44,12 @@ def test_auto_mapper_full(spark_session_per_function: SparkSession):
             )
         )
 
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs()
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    result_df: DataFrame = mapper.transform(df=df)
+    mapper.transform(df=source_df)
+    result_df: DataFrame = spark_session.table("members")
 
     # Assert
     result_df.printSchema()
