@@ -7,7 +7,7 @@ from pyspark.sql.functions import lit
 from spark_auto_mapper.automappers.automapper import AutoMapper
 
 
-def test_auto_mapper_with_column_literal(spark_session: SparkSession):
+def test_auto_mapper_with_column_literal(spark_session: SparkSession) -> None:
     # Arrange
     spark_session.createDataFrame(
         [
@@ -27,12 +27,12 @@ def test_auto_mapper_with_column_literal(spark_session: SparkSession):
         view="members",
         source_view="patients",
         keys=["member_id"]
-    ).withColumn(
+    ).columns(
         lname="last_name"
     )
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs()
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
